# Generated by roxygen2: do not edit by hand

S3method(plot,CharAnalysis)
S3method(print,CharAnalysis)
S3method(summary,CharAnalysis)
export(CharAnalysis)
export(char_parameters)
export(char_plot_all)
export(char_plot_cumulative)
export(char_plot_fire_history)
export(char_plot_fri)
export(char_plot_peaks)
export(char_plot_raw)
export(char_plot_sni)
export(char_plot_thresh_diag)
export(char_plot_zones)
export(char_write_results)
importFrom(MASS,fitdistr)
importFrom(graphics,hist)
importFrom(stats,approx)
importFrom(stats,approxfun)
importFrom(stats,dnorm)
importFrom(stats,ks.test)
importFrom(stats,lowess)
importFrom(stats,median)
importFrom(stats,pnorm)
importFrom(stats,pweibull)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(utils,read.csv)
importFrom(utils,write.table)
importFrom(zoo,rollapply)
